/**
 * Abstract service
 * @class ApService
 */
'use strict'

const abind = require('abind')
const { Apemanstore } = require('apemanstore')

/** @lends ApService */
class ApService {
  constructor (store) {
    ApService.assertStore(store)

    const s = this
    s.store = store
    abind(s, { proto: ApService.prototype })
    // noinspection Eslint
    abind(s, { proto: s.__proto__.prototype })
  }

  /**
   * Get a store value
   * @param {string} key - Key to get
   * @returns {*} Value
   */
  get (key) {
    const s = this
    let { store } = s
    return store.get(key)
  }

  /**
   * Set a store value
   * @param {string} key - Key to set
   * @param {*} value - Value to set
   */
  set (key, value) {
    const s = this
    let { store } = s
    return store.set(key, value)
  }

  static assertStore (store) {
    let isApemanstore = store instanceof Apemanstore
    if (!isApemanstore) {
      throw new Error(`store should be an instance of Apemanstore`)
    }
  }
}

module.exports = ApService
